@@ -1,15 +1,11 @@
 import ChildScope from '../scopes/ChildScope';
-import Identifier from './Identifier';
+import { IdentifierWithVariable } from './Identifier';
 import * as NodeType from './NodeType';
 import FunctionNode from './shared/FunctionNode';
-import { GenericEsTreeNode, Node } from './shared/Node';
-
-export function isFunctionDeclaration(node: Node): node is FunctionDeclaration {
-	return node.type === NodeType.FunctionDeclaration;
-}
+import { GenericEsTreeNode } from './shared/Node';
 
 export default class FunctionDeclaration extends FunctionNode {
-	type: NodeType.tFunctionDeclaration;
+	type!: NodeType.tFunctionDeclaration;
 
 	initialise() {
 		super.initialise();
@@ -20,11 +16,8 @@ export default class FunctionDeclaration extends FunctionNode {
 
 	parseNode(esTreeNode: GenericEsTreeNode) {
 		if (esTreeNode.id !== null) {
-			this.id = <Identifier>(
-				new this.context.nodeConstructors.Identifier(esTreeNode.id, this, <ChildScope>(
-					this.scope.parent
-				))
-			);
+			this.id = new this.context.nodeConstructors.Identifier(esTreeNode.id, this, this.scope
+				.parent as ChildScope) as IdentifierWithVariable;
 		}
 		super.parseNode(esTreeNode);
 	}
