@@ -1,13 +1,13 @@
-System.register(['./generated-chunk.js', './generated-chunk2.js', './generated-chunk3.js'], function (exports, module) {
+System.register(['./generated-broken.js', './generated-foo.js', './generated-bar.js'], function () {
 	'use strict';
 	var broken, foo, bar;
 	return {
 		setters: [function (module) {
-			broken = module.a;
+			broken = module.b;
 		}, function (module) {
-			foo = module.a;
+			foo = module.f;
 		}, function (module) {
-			bar = module.a;
+			bar = module.b;
 		}],
 		execute: function () {
 
