@@ -1,6 +1,6 @@
 (function (global, factory) {
 	typeof exports === 'object' && typeof module !== 'undefined' ? factory(require('./lib/throttle.js')) :
-	typeof define === 'function' && define.amd ? define(['./lib/throttle.js'], factory) :
+	typeof define === 'function' && define.amd ? define(['./lib/throttle'], factory) :
 	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.Lib.throttle));
 }(this, (function (throttle) { 'use strict';
 
