@@ -111,7 +111,8 @@ module.exports = {
 							importers: [],
 							isEntry: true,
 							isExternal: false,
-							meta: {}
+							meta: {},
+							syntheticNamedExports: false
 						},
 						{
 							ast: null,
@@ -126,7 +127,8 @@ module.exports = {
 							importers: [getId('main')],
 							isEntry: false,
 							isExternal: true,
-							meta: {}
+							meta: {},
+							syntheticNamedExports: false
 						},
 						{
 							ast: {
@@ -154,7 +156,8 @@ module.exports = {
 							importers: [getId('dynamic'), getId('main')],
 							isEntry: false,
 							isExternal: false,
-							meta: {}
+							meta: {},
+							syntheticNamedExports: false
 						},
 						{
 							ast: {
@@ -226,7 +229,8 @@ module.exports = {
 							importers: [],
 							isEntry: false,
 							isExternal: false,
-							meta: {}
+							meta: {},
+							syntheticNamedExports: false
 						}
 					]
 				);
